@@ -334,7 +334,7 @@ parser_exon.add_argument('-d', '--database', type=str, required=True,
                          help='database generated by subcommand create')
 parser_exon.add_argument('-f', '--genome', type=str, required=True, 
                          help='genome fasta')
-parser_exon.add_argument('-t', '--transcript', type=str, required=True, 
+parser_exon.add_argument('-t', '--transcript', type=str, 
                          help='specific transcript id; needed')
 parser_exon.add_argument('-o', '--output', type=str, 
                          help='output file path')
